package com.zh.project0512.controller.manage;


import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.zh.project0512.annotation.AdminTokenValid;
import com.zh.project0512.model.User;
import com.zh.project0512.service.IQywxDepartmentService;
import com.zh.project0512.service.IUserService;
import com.zh.project0512.utils.MybatisPlusUtil;
import com.zh.project0512.utils.result.Result;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.Data;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author zh
 * @since 2022-05-18
 */
@Tag(name = "成员管理")
@RestController
@RequestMapping("/manage/user")
public class UserController {

    @Autowired
    private IUserService userService;

    @Autowired
    private IQywxDepartmentService qywxDepartmentService;

    @Data
    static class UParam {
        private Integer pageNum;
        private Integer pageSize;
        @Schema(title = "人员名称")
        private String name;
        @Schema(title = "部门名称")
        private String department;
    }

    @Operation(summary = "成员列表")
    @PostMapping("/list")
    @AdminTokenValid
    public Result addTag(@Validated @RequestBody UParam param) {
        QueryWrapper<User> qw = new QueryWrapper<>();
        qw
            .and(param.getDepartment() !=null,q -> q.like( "t2.name",param.getDepartment())
            .or(o -> o.like( "t3.name",param.getDepartment())))
            .like(param.getName() !=null, "t1.name",param.getName());
        return Result.success(userService.pageList(MybatisPlusUtil.SetNumPage(param.getPageNum(),param.getPageSize()),qw));
    }

    @Operation(summary = "部门列表")
    @PostMapping("/department")
    @AdminTokenValid
    public Result department(@RequestBody JSONObject obj) {
        return Result.success(qywxDepartmentService.list(MybatisPlusUtil.SetPage(obj)));
    }

}
